UnsupportedLanguageException class

Exception thrown when a language code is not supported.

Inheritance

Constructors

UnsupportedLanguageException(String languageCode)
Creates an UnsupportedLanguageException for the given languageCode.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
languageCode String
The unsupported language code.
final
message String
The error message describing what went wrong.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited