ArbAnalysisResult class
Result of ARB file analysis.
Constructors
-
ArbAnalysisResult({required String baseLocale, required int baseKeyCount, required Map<
String, ArbFileAnalysis> fileAnalysis}) -
Creates an ArbAnalysisResult with the given parameters.
const
Properties
- baseKeyCount → int
-
Total number of keys in the base file.
final
- baseLocale → String
-
The base locale used for comparison.
final
-
fileAnalysis
→ Map<
String, ArbFileAnalysis> -
Analysis results for each ARB file.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- overallCompleteness → double
-
Gets overall project completeness percentage.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalMissingKeys → int
-
Gets total number of missing keys across all files.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited