ArbFileAnalysis class
Analysis result for a single ARB file.
Constructors
-
ArbFileAnalysis({required int totalKeys, required Set<
String> missingKeys, required Set<String> extraKeys, required List<String> placeholderIssues, required double completenessPercentage}) -
Creates an ArbFileAnalysis with the given parameters.
const
Properties
- completenessPercentage → double
-
Completeness percentage (0.0 to 100.0).
final
-
extraKeys
→ Set<
String> -
Keys that exist in this file but not in the base file.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasIssues → bool
-
Whether this file has any issues.
no setter
-
missingKeys
→ Set<
String> -
Keys that are missing compared to the base file.
final
-
placeholderIssues
→ List<
String> -
Keys with placeholder consistency issues.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalKeys → int
-
Total number of translation keys in this file.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited